Package: xtable
Version: 1.8-4
Date: 2019-04-08
Title: Export Tables to LaTeX or HTML
Authors@R: c(person("David B.", "Dahl", role="aut"),
             person("David", "Scott", role=c("aut","cre"),
               email="d.scott@auckland.ac.nz"),
             person("Charles", "Roosen", role="aut"),
             person("Arni", "Magnusson", role="aut"),
             person("Jonathan", "Swinton", role="aut"),
             person("Ajay", "Shah", role="ctb"),
             person("Arne", "Henningsen", role="ctb"),
             person("Benno", "Puetz", role="ctb"),
             person("Bernhard", "Pfaff", role="ctb"),
             person("Claudio", "Agostinelli", role="ctb"),
             person("Claudius", "Loehnert", role="ctb"),
             person("David", "Mitchell", role="ctb"),
             person("David", "Whiting", role="ctb"),
             person("Fernando da", "Rosa", role="ctb"),
             person("Guido", "Gay", role="ctb"),
             person("Guido", "Schulz", role="ctb"),
             person("Ian", "Fellows", role="ctb"),
             person("Jeff", "Laake", role="ctb"),
             person("John", "Walker", role="ctb"),
             person("Jun", "Yan", role="ctb"),
             person("Liviu", "Andronic", role="ctb"),
             person("Markus", "Loecher", role="ctb"),
             person("Martin", "Gubri", role="ctb"),
             person("Matthieu", "Stigler", role="ctb"),
             person("Robert", "Castelo", role="ctb"),
             person("Seth", "Falcon", role="ctb"),
             person("Stefan", "Edwards", role="ctb"),
             person("Sven", "Garbade", role="ctb"),
             person("Uwe", "Ligges", role="ctb"))
Maintainer: David Scott <d.scott@auckland.ac.nz>
Imports: stats, utils
Suggests: knitr, plm, zoo, survival
VignetteBuilder: knitr
Description: Coerce data to LaTeX and HTML tables.
URL: http://xtable.r-forge.r-project.org/
Depends: R (>= 2.10.0)
License: GPL (>= 2)
Repository: CRAN
NeedsCompilation: no
Packaged: 2019-04-21 10:56:51 UTC; dsco036
Author: David B. Dahl [aut],
  David Scott [aut, cre],
  Charles Roosen [aut],
  Arni Magnusson [aut],
  Jonathan Swinton [aut],
  Ajay Shah [ctb],
  Arne Henningsen [ctb],
  Benno Puetz [ctb],
  Bernhard Pfaff [ctb],
  Claudio Agostinelli [ctb],
  Claudius Loehnert [ctb],
  David Mitchell [ctb],
  David Whiting [ctb],
  Fernando da Rosa [ctb],
  Guido Gay [ctb],
  Guido Schulz [ctb],
  Ian Fellows [ctb],
  Jeff Laake [ctb],
  John Walker [ctb],
  Jun Yan [ctb],
  Liviu Andronic [ctb],
  Markus Loecher [ctb],
  Martin Gubri [ctb],
  Matthieu Stigler [ctb],
  Robert Castelo [ctb],
  Seth Falcon [ctb],
  Stefan Edwards [ctb],
  Sven Garbade [ctb],
  Uwe Ligges [ctb]
Date/Publication: 2019-04-21 12:20:03 UTC
Built: R 4.4.2; ; 2025-10-26 02:58:03 UTC; unix
