importFrom("utils", "toLatex")
importFrom("stats", "anova", "as.ts", "cycle", "end", "frequency",
           "na.omit", "pchisq", "start", "time")
importFrom("utils", "packageDescription")
export("caption<-", "caption", "label", "label<-",
       "align<-", "align", "digits<-", "digits", "display<-",
       "display", "xtable",
       "xtableMatharray","xtableList", "xtableLSMeans",
       "print.xtable", "print.xtableMatharray", "print.xtableList",
       "xtableFtable", "print.xtableFtable",
       "toLatex.xtable",
       "autoformat", "xalign", "xdigits", "xdisplay",
       "sanitize", "sanitize.numbers", "sanitize.final", "as.is", "as.math")

S3method("print", "xtable")
S3method("print", "xtableMatharray")
S3method("print", "xtableList")
S3method("print", "xtableFtable")
S3method("toLatex", "xtable")

S3method("caption<-", "xtable")
S3method("caption", "xtable")
S3method("label", "xtable")
S3method("label<-", "xtable")
S3method("align<-", "xtable")
S3method("align", "xtable")
S3method("digits", "xtable")
S3method("digits<-", "xtable")
S3method("display<-", "xtable")
S3method("display", "xtable")

S3method("xtable", "data.frame")
S3method("xtable", "matrix")
S3method("xtable", "table")
S3method("xtable", "anova")
S3method("xtable", "aov")
S3method("xtable", "summary.aov")
S3method("xtable", "summary.aovlist")
S3method("xtable", "aovlist")
S3method("xtable", "lm")
S3method("xtable", "summary.lm")
S3method("xtable", "glm")
S3method("xtable", "summary.glm")
S3method("xtable", "prcomp")
S3method("xtable", "summary.prcomp")
S3method("xtable", "coxph")
S3method("xtable", "ts")
S3method("xtable", "zoo")
## S3method("xtable", "sarlm")
## S3method("xtable", "summary.sarlm")
## S3method("xtable", "gmsar")
## S3method("xtable", "summary.gmsar")
## S3method("xtable", "stsls")
## S3method("xtable", "summary.stsls")
## S3method("xtable", "sarlm.pred")
## S3method("xtable", "lagImpact")
## S3method("xtable", "splm")
## S3method("xtable", "summary.splm")
## S3method("xtable", "sphet")
## S3method("xtable", "summary.sphet")
## S3method("xtable", "spautolm")
## S3method("xtable", "summary.spautolm")
